This repository contains implementations of various architectures used in `Computer Vision`.

Most implementations that are provided alongside research papers are with keeping 2D natural images in mind. However, there are many use cases where the same architectures are desired for a 3D space, for eg. in medical imaging, video games, environment reconstruction etc. For this reason, many (but not all) of the architectures in this repository are 3D implementations of popular research papers.

Visit https://www.agarwalarjun.com/vision_architectures/ for the complete documentation.